# Authentication to SAP LeanIX Services
### On this page
  * [Authentication Flow](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services#authentication-flow)
  * [Step 1: Get an API Token](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services#step-1:-get-an-api-token)
  * [Step 2: Get an Access Token](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services#step-2:-get-an-access-token)
  * [Step 3: Make Authenticated Requests to Services](https://help.sap.com/docs/leanix/ea/authentication-to-sap-leanix-services#step-3:-make-authenticated-requests-to-services)


Learn how to authenticate to SAP LeanIX services.
In this guide, you will learn how authentication to SAP LeanIX services works.
To authenticate your requests, follow these key steps:
  1. Get an API token by creating a Technical User.
  2. Get an access token.
  3. Make authenticated requests to services by including the access token in the Authorization header.


**Note**
Before you begin, make sure that you know your SAP LeanIX subdomain. You can copy your subdomain value from the Workspace URL. To learn more, see [Base URL](https://help.sap.com/docs/leanix/ea/base-url?locale=en-US&state=PRODUCTION&version=CLOUD "Learn about the SAP LeanIX base URL and how to get your subdomain value.").
